@@ -16,8 +16,8 @@ from .milestones import RE_MIL, MilestoneProcessor
 from .gaps_spaces import (
     CompleteSquareBrackets,
     RE_SPACE, SpaceProcessor,
-    RE_LINE_GAP, LineGapProcessor,
-    RE_CHARACTER_GAP, CharacterGapProcessor,
+    RE_LINE_LOST, LineGapProcessor,
+    RE_CHARACTER_LOST, RE_CHARACTER_ILLEGIBLE, CharacterGapProcessor,
     RE_SUPPLIED, SuppliedProcessor
 )
 from .foreign import RE_FOREIGN, ForeignProcessor
@@ -55,10 +55,11 @@ class LeidenPlus(Extension):
         md.parser.blockprocessors.register(TrivialProcessor(md.parser), 'fallback', 0)
         md.inlinePatterns.register(MilestoneProcessor(RE_MIL, md), 'milestones', 120)
         md.inlinePatterns.register(SpaceProcessor(RE_SPACE, md), 'spaces', 119)
-        md.inlinePatterns.register(LineGapProcessor(RE_LINE_GAP, md), 'line_gaps', 118)
-        md.inlinePatterns.register(CharacterGapProcessor(RE_CHARACTER_GAP, md), 'character_gaps', 117)
+        md.inlinePatterns.register(LineGapProcessor(RE_LINE_LOST, md), 'line_gaps', 118)
+        md.inlinePatterns.register(CharacterGapProcessor(RE_CHARACTER_LOST, md, reason='lost'), 'character_lost', 117)
         md.inlinePatterns.register(ForeignProcessor(RE_FOREIGN, md), 'foreign', 116)
         md.inlinePatterns.register(SuppliedProcessor(RE_SUPPLIED, md), 'supplied', 5)
+        md.inlinePatterns.register(CharacterGapProcessor(RE_CHARACTER_ILLEGIBLE, md, reason='illegible'), 'character_illegible', 4)
         md.inlinePatterns.register(HetaProcessor(RE_HETA, md), 'heta', 49) # After UnderscoreProcessor
         md.treeprocessors.register(DivisionMarkTreeproc(md), 'divison_treeproc', 120)
         md.treeprocessors.register(ColumnContainerTreeproc(md), 'col_container', 119)
