@@ -4,6 +4,7 @@ from xml.etree import ElementTree as etree
 from markdown.preprocessors import Preprocessor
 from markdown.blockprocessors import BlockProcessor
 from markdown.treeprocessors import Treeprocessor
+from markdown.postprocessors import Postprocessor
 
 from .exceptions import LeidenPlusSyntaxError
 
@@ -135,6 +136,39 @@ class DivisionMarkTreeproc(Treeprocessor):
                 el_close = root.find(f'./{tag}-CLOSE')
 
 
+class ColumnContainerTreeproc(Treeprocessor):
+    """ Wrap column-like divisions in a <seg type="columns"/> container """
+
+    def _is(self, tag_name, el):
+        return el.tag == 'div' and el.attrib.get('type') == 'textpart' and el.attrib.get('subtype') == tag_name
+
+    def insert_containers(self, root, tag_name, seg_attribs={}):
+        # Select all parents of columns
+        for parent in root.findall(f'.//div[@subtype="{tag_name}"]/..'):
+            for i in range(len(root)):
+                try:
+                    el = parent[i]
+                except IndexError:
+                    break
+                else:
+                    if self._is(tag_name, el):
+                        col_container = etree.Element('seg', type='columns', **seg_attribs)
+                        parent.insert(i, col_container)
+                        while self._is(tag_name, el):
+                            col_container.append(el)
+                            parent.remove(el)
+                            try:
+                                el = parent[i + 1]
+                            except IndexError:
+                                break
+
+    def run(self, root):
+        self.insert_containers(root, 'column')
+        self.insert_containers(root, 'tab', seg_attribs={'rend': 'hide-labels'})
+
+
+THROWAWAY_TAG = 'throwaway-p'
+
 class TrivialProcessor(BlockProcessor):
     """ Fallback alternative to the ParagraphProcessor. """
 
@@ -143,16 +177,15 @@ class TrivialProcessor(BlockProcessor):
 
     def run(self, parent, blocks):
         block = blocks.pop(0)
-        content = block
-        children = list(parent)
-        if len(children) == 0:
-            if parent.text:
-                parent.text += content
-            else:
-                parent.text = content
-        else:
-            last_child = children[-1]
-            if last_child.tail:
-                last_child.tail += content
-            else:
-                last_child.tail = content
+        if block.strip():
+            # In order for inlineprocessors to work, we have to wrap the content in
+            # at least one element. Therefore we create this throwaway which we filter
+            # in post-processing.
+            p = etree.SubElement(parent, THROWAWAY_TAG)
+            p.text = block.lstrip()
+
+
+class RemoveThrowaway(Postprocessor):
+    """ Remove throwaway that TrivialProcessor creates """
+    def run(self, text):
+        return re.sub(f'\s*\<\s*/?\s*{THROWAWAY_TAG}\s*/?\s*\>\s*', '', text)
